@@ -1,9 +1,11 @@
+"""Firepup650's fkeycapture module"""
 import termios, fcntl, sys
 global fd,flags_save,attrs_save
 fd = sys.stdin.fileno()
 flags_save = fcntl.fcntl(fd, fcntl.F_GETFL)
 attrs_save = termios.tcgetattr(fd)
-def getp1():
+def __getp1():
+    """Internal Method"""
     import termios, fcntl, sys, os
     fd = sys.stdin.fileno()
     # save old state
@@ -26,17 +28,40 @@ def getp1():
     termios.tcsetattr(fd, termios.TCSANOW, attrs)
     # turn off non-blocking
     fcntl.fcntl(fd, fcntl.F_SETFL, flags_save & ~os.O_NONBLOCK)
-def getp2():
+def __getp2():
+    """Internal Method"""
     termios.tcsetattr(fd, termios.TCSAFLUSH, attrs_save)
     fcntl.fcntl(fd, fcntl.F_SETFL, flags_save)
-def get(keycount=1,bytes=False):
-  getp1()
+def get(keycount: int = 1, bytes: bool = False) -> str or bytes:
+  """# Function: get
+
+# Inputs:
+  keycount: int - Number of keys, defualts to 1
+  bytes: bool   - Wether or not to return the key(s) as bytes, defaults to False
+
+# Returns:
+  str or bytes
+
+# Raises:
+  None"""
+  __getp1()
   key = sys.stdin.read(keycount)
-  getp2()
+  __getp2()
   if bytes == True:
     key = key.encode()
   return key
-def getnum(keycount=1):
+def getnum(keycount: int = 1, ints: bool = False) -> str or int:
+  """# Function: getnum
+
+# Inputs:
+  keycount: int - Number of keys, defualts to 1
+  ints: bool    - Wether to return the keys as ints, defaults to False
+
+# Returns:
+  str or int
+
+# Raises:
+  None"""
   internalcounter=0
   keys = []
   while internalcounter != keycount:
@@ -45,8 +70,22 @@ def getnum(keycount=1):
       keys.append(key)
       internalcounter += 1
   key = "".join(keys)
-  return key
-def getchars(keycount=1,chars=["1","2"]):
+  if not ints:
+    return key
+  else:
+    return int(key)
+def getchars(keycount: int = 1, chars: list = ["1", "2"]) -> str:
+  """# Function: getchars
+
+# Inputs:
+  keycount: int - Number of keys, defualts to 1
+  chars: list   - List of allowed keys, defaults to ["1", "2"]
+
+# Returns:
+  str
+
+# Raises:
+  None"""
   internalcounter=0
   keys = []
   while internalcounter != keycount:
@@ -57,5 +96,15 @@ def getchars(keycount=1,chars=["1","2"]):
         internalcounter += 1
   key = "".join(keys)
   return key
-def help():
-  print("FKEYCAPTURE HELP\nThis is a simple and easy to use package that allows you to capture individual keystrokes from the user.\nFORMS:\n1. (Default) Recive key as a string\n2. Recive key as bytes\nHOW TO USE:\n1. from fkeycapture import get, getnum, getchars\n2. Use get like this: get([number of keys to capture],[if you want bytes output, make this 'True'])\n3. Use getnum like this: getnum([number of numbers to capture])\n4. Use getchars like this: get([number of keys to capture],[list of chars to capture])")
\ No newline at end of file
+# def help():
+#   """# Function: help
+
+# # Inputs:
+#   None
+
+# # Returns:
+#   None
+
+# # Raises:
+#   None"""
+#   print("FKEYCAPTURE HELP\nThis is a simple and easy to use package that allows you to capture individual keystrokes from the user.\nFORMS:\n1. (Default) Recive key as a string\n2. Recive key as bytes\nHOW TO USE:\n1. from fkeycapture import get, getnum, getchars\n2. Use get like this: get([number of keys to capture],[if you want bytes output, make this 'True'])\n3. Use getnum like this: getnum([number of numbers to capture])\n4. Use getchars like this: get([number of keys to capture],[list of chars to capture])")
\ No newline at end of file
